geowatch.utils.lightning\_ext.callbacks.packager module
=======================================================

.. automodule:: geowatch.utils.lightning_ext.callbacks.packager
   :members:
   :undoc-members:
   :show-inheritance:
